@@ -9,17 +9,26 @@
  */
 
 if ( ! class_exists( 'POMO_Reader', false ) ) :
+	#[AllowDynamicProperties]
 	class POMO_Reader {
 
 		public $endian = 'little';
-		public $_post  = '';
+		public $_pos;
+		public $is_overloaded;
 
 		/**
 		 * PHP5 constructor.
 		 */
-		function __construct() {
-			$this->is_overloaded = ( ( ini_get( 'mbstring.func_overload' ) & 2 ) != 0 ) && function_exists( 'mb_substr' ); // phpcs:ignore PHPCompatibility.IniDirectives.RemovedIniDirectives.mbstring_func_overloadDeprecated
-			$this->_pos          = 0;
+		public function __construct() {
+			if ( function_exists( 'mb_substr' )
+				&& ( (int) ini_get( 'mbstring.func_overload' ) & 2 ) // phpcs:ignore PHPCompatibility.IniDirectives.RemovedIniDirectives.mbstring_func_overloadDeprecated
+			) {
+				$this->is_overloaded = true;
+			} else {
+				$this->is_overloaded = false;
+			}
+
+			$this->_pos = 0;
 		}
 
 		/**
@@ -39,7 +48,7 @@ if ( ! class_exists( 'POMO_Reader', false ) ) :
 		 *
 		 * @param string $endian Set the endianness of the file. Accepts 'big', or 'little'.
 		 */
-		function setEndian( $endian ) { // phpcs:ignore WordPress.NamingConventions.ValidFunctionName.MethodNameInvalid
+		public function setEndian( $endian ) { // phpcs:ignore WordPress.NamingConventions.ValidFunctionName.MethodNameInvalid
 			$this->endian = $endian;
 		}
 
@@ -49,7 +58,7 @@ if ( ! class_exists( 'POMO_Reader', false ) ) :
 		 * @return mixed The integer, corresponding to the next 32 bits from
 		 *  the stream of false if there are not enough bytes or on error
 		 */
-		function readint32() {
+		public function readint32() {
 			$bytes = $this->read( 4 );
 			if ( 4 != $this->strlen( $bytes ) ) {
 				return false;
@@ -66,7 +75,7 @@ if ( ! class_exists( 'POMO_Reader', false ) ) :
 		 * @return mixed Array of integers or false if there isn't
 		 *  enough data or on error
 		 */
-		function readint32array( $count ) {
+		public function readint32array( $count ) {
 			$bytes = $this->read( 4 * $count );
 			if ( 4 * $count != $this->strlen( $bytes ) ) {
 				return false;
@@ -76,67 +85,67 @@ if ( ! class_exists( 'POMO_Reader', false ) ) :
 		}
 
 		/**
-		 * @param string $string
+		 * @param string $input_string
 		 * @param int    $start
 		 * @param int    $length
 		 * @return string
 		 */
-		function substr( $string, $start, $length ) {
+		public function substr( $input_string, $start, $length ) {
 			if ( $this->is_overloaded ) {
-				return mb_substr( $string, $start, $length, 'ascii' );
+				return mb_substr( $input_string, $start, $length, 'ascii' );
 			} else {
-				return substr( $string, $start, $length );
+				return substr( $input_string, $start, $length );
 			}
 		}
 
 		/**
-		 * @param string $string
+		 * @param string $input_string
 		 * @return int
 		 */
-		function strlen( $string ) {
+		public function strlen( $input_string ) {
 			if ( $this->is_overloaded ) {
-				return mb_strlen( $string, 'ascii' );
+				return mb_strlen( $input_string, 'ascii' );
 			} else {
-				return strlen( $string );
+				return strlen( $input_string );
 			}
 		}
 
 		/**
-		 * @param string $string
+		 * @param string $input_string
 		 * @param int    $chunk_size
 		 * @return array
 		 */
-		function str_split( $string, $chunk_size ) {
+		public function str_split( $input_string, $chunk_size ) {
 			if ( ! function_exists( 'str_split' ) ) {
-				$length = $this->strlen( $string );
+				$length = $this->strlen( $input_string );
 				$out    = array();
 				for ( $i = 0; $i < $length; $i += $chunk_size ) {
-					$out[] = $this->substr( $string, $i, $chunk_size );
+					$out[] = $this->substr( $input_string, $i, $chunk_size );
 				}
 				return $out;
 			} else {
-				return str_split( $string, $chunk_size );
+				return str_split( $input_string, $chunk_size );
 			}
 		}
 
 		/**
 		 * @return int
 		 */
-		function pos() {
+		public function pos() {
 			return $this->_pos;
 		}
 
 		/**
 		 * @return true
 		 */
-		function is_resource() {
+		public function is_resource() {
 			return true;
 		}
 
 		/**
 		 * @return true
 		 */
-		function close() {
+		public function close() {
 			return true;
 		}
 	}
@@ -145,10 +154,17 @@ endif;
 if ( ! class_exists( 'POMO_FileReader', false ) ) :
 	class POMO_FileReader extends POMO_Reader {
 
+		/**
+		 * File pointer resource.
+		 *
+		 * @var resource|false
+		 */
+		public $_f;
+
 		/**
 		 * @param string $filename
 		 */
-		function __construct( $filename ) {
+		public function __construct( $filename ) {
 			parent::__construct();
 			$this->_f = fopen( $filename, 'rb' );
 		}
@@ -169,7 +185,7 @@ if ( ! class_exists( 'POMO_FileReader', false ) ) :
 		 * @param int $bytes
 		 * @return string|false Returns read string, otherwise false.
 		 */
-		function read( $bytes ) {
+		public function read( $bytes ) {
 			return fread( $this->_f, $bytes );
 		}
 
@@ -177,7 +193,7 @@ if ( ! class_exists( 'POMO_FileReader', false ) ) :
 		 * @param int $pos
 		 * @return bool
 		 */
-		function seekto( $pos ) {
+		public function seekto( $pos ) {
 			if ( -1 == fseek( $this->_f, $pos, SEEK_SET ) ) {
 				return false;
 			}
@@ -188,33 +204,29 @@ if ( ! class_exists( 'POMO_FileReader', false ) ) :
 		/**
 		 * @return bool
 		 */
-		function is_resource() {
+		public function is_resource() {
 			return is_resource( $this->_f );
 		}
 
 		/**
 		 * @return bool
 		 */
-		function feof() {
+		public function feof() {
 			return feof( $this->_f );
 		}
 
 		/**
 		 * @return bool
 		 */
-		function close() {
+		public function close() {
 			return fclose( $this->_f );
 		}
 
 		/**
 		 * @return string
 		 */
-		function read_all() {
-			$all = '';
-			while ( ! $this->feof() ) {
-				$all .= $this->read( 4096 );
-			}
-			return $all;
+		public function read_all() {
+			return stream_get_contents( $this->_f );
 		}
 	}
 endif;
@@ -231,7 +243,7 @@ if ( ! class_exists( 'POMO_StringReader', false ) ) :
 		/**
 		 * PHP5 constructor.
 		 */
-		function __construct( $str = '' ) {
+		public function __construct( $str = '' ) {
 			parent::__construct();
 			$this->_str = $str;
 			$this->_pos = 0;
@@ -253,7 +265,7 @@ if ( ! class_exists( 'POMO_StringReader', false ) ) :
 		 * @param string $bytes
 		 * @return string
 		 */
-		function read( $bytes ) {
+		public function read( $bytes ) {
 			$data        = $this->substr( $this->_str, $this->_pos, $bytes );
 			$this->_pos += $bytes;
 			if ( $this->strlen( $this->_str ) < $this->_pos ) {
@@ -266,7 +278,7 @@ if ( ! class_exists( 'POMO_StringReader', false ) ) :
 		 * @param int $pos
 		 * @return int
 		 */
-		function seekto( $pos ) {
+		public function seekto( $pos ) {
 			$this->_pos = $pos;
 			if ( $this->strlen( $this->_str ) < $this->_pos ) {
 				$this->_pos = $this->strlen( $this->_str );
@@ -277,14 +289,14 @@ if ( ! class_exists( 'POMO_StringReader', false ) ) :
 		/**
 		 * @return int
 		 */
-		function length() {
+		public function length() {
 			return $this->strlen( $this->_str );
 		}
 
 		/**
 		 * @return string
 		 */
-		function read_all() {
+		public function read_all() {
 			return $this->substr( $this->_str, $this->_pos, $this->strlen( $this->_str ) );
 		}
 
@@ -299,7 +311,7 @@ if ( ! class_exists( 'POMO_CachedFileReader', false ) ) :
 		/**
 		 * PHP5 constructor.
 		 */
-		function __construct( $filename ) {
+		public function __construct( $filename ) {
 			parent::__construct();
 			$this->_str = file_get_contents( $filename );
 			if ( false === $this->_str ) {
@@ -341,7 +353,7 @@ if ( ! class_exists( 'POMO_CachedIntFileReader', false ) ) :
 		 *
 		 * @see POMO_CachedIntFileReader::__construct()
 		 */
-		function POMO_CachedIntFileReader( $filename ) {
+		public function POMO_CachedIntFileReader( $filename ) {
 			_deprecated_constructor( self::class, '5.4.0', static::class );
 			self::__construct( $filename );
 		}
